emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 30a1d5d: Remove stray copy of image-tests.el


From: Paul Eggert
Subject: master 30a1d5d: Remove stray copy of image-tests.el
Date: Fri, 1 Jan 2021 05:04:25 -0500 (EST)

branch: master
commit 30a1d5da7a43d51a97cbe8d91add9a26dd99df90
Author: Paul Eggert <eggert@cs.ucla.edu>
Commit: Paul Eggert <eggert@cs.ucla.edu>

    Remove stray copy of image-tests.el
    
    * test/manual/image-circular-tests.el: Remove a stray copy of
    image-tests.el that was appended to this file.  Found by its
    duplicate copyright notice.
---
 test/manual/image-circular-tests.el | 85 ++-----------------------------------
 1 file changed, 3 insertions(+), 82 deletions(-)

diff --git a/test/manual/image-circular-tests.el 
b/test/manual/image-circular-tests.el
index 28b5f89..3d1d232 100644
--- a/test/manual/image-circular-tests.el
+++ b/test/manual/image-circular-tests.el
@@ -1,4 +1,4 @@
 ;;; image-tests.el --- Test suite for image-related functions.
 
 ;; Copyright (C) 2019, 2021 Free Software Foundation, Inc.
 
@@ -61,84 +61,5 @@
      (and (equal (image-size spec1 t) (cons 1 1))
           (equal (image-size spec2 t) (cons 1 1))))))
 
-(provide 'image-tests)
-;;; image-tests.el ends here.
-;;; image-tests.el --- tests for image.el -*- lexical-binding: t -*-
-
-;; Copyright (C) 2019-2020 Free Software Foundation, Inc.
-
-;; This file is part of GNU Emacs.
-
-;; GNU Emacs is free software: you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation, either version 3 of the License, or
-;; (at your option) any later version.
-
-;; GNU Emacs is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;; GNU General Public License for more details.
-
-;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs.  If not, see <https://www.gnu.org/licenses/>.
-
-;;; Code:
-
-(require 'ert)
-(require 'image)
-(eval-when-compile
-  (require 'cl-lib))
-
-(defconst image-tests--emacs-images-directory
-  (expand-file-name "../etc/images" (getenv "EMACS_TEST_DIRECTORY"))
-  "Directory containing Emacs images.")
-
-(ert-deftest image--set-property ()
-  "Test `image--set-property' behavior."
-  (let ((image (list 'image)))
-    ;; Add properties.
-    (setf (image-property image :scale) 1)
-    (should (equal image '(image :scale 1)))
-    (setf (image-property image :width) 8)
-    (should (equal image '(image :scale 1 :width 8)))
-    (setf (image-property image :height) 16)
-    (should (equal image '(image :scale 1 :width 8 :height 16)))
-    ;; Delete properties.
-    (setf (image-property image :type) nil)
-    (should (equal image '(image :scale 1 :width 8 :height 16)))
-    (setf (image-property image :scale) nil)
-    (should (equal image '(image :width 8 :height 16)))
-    (setf (image-property image :height) nil)
-    (should (equal image '(image :width 8)))
-    (setf (image-property image :width) nil)
-    (should (equal image '(image)))))
-
-(ert-deftest image-type-from-file-header-test ()
-  "Test image-type-from-file-header."
-  (should (eq (if (image-type-available-p 'svg) 'svg)
-             (image-type-from-file-header
-              (expand-file-name "splash.svg"
-                                image-tests--emacs-images-directory)))))
-
-(ert-deftest image-rotate ()
-  "Test `image-rotate'."
-  (cl-letf* ((image (list 'image))
-             ((symbol-function 'image--get-imagemagick-and-warn)
-              (lambda () image)))
-    (let ((current-prefix-arg '(4)))
-      (call-interactively #'image-rotate))
-    (should (equal image '(image :rotation 270.0)))
-    (call-interactively #'image-rotate)
-    (should (equal image '(image :rotation 0.0)))
-    (image-rotate)
-    (should (equal image '(image :rotation 90.0)))
-    (image-rotate 0)
-    (should (equal image '(image :rotation 90.0)))
-    (image-rotate 1)
-    (should (equal image '(image :rotation 91.0)))
-    (image-rotate 1234.5)
-    (should (equal image '(image :rotation 245.5)))
-    (image-rotate -154.5)
-    (should (equal image '(image :rotation 91.0)))))
-
-;;; image-tests.el ends here
+(provide 'image-circular-tests)
+;;; image-circular-tests.el ends here.
@@ -1,4 +1,4 @@
-;;; image-tests.el --- Test suite for image-related functions.
+;;; image-circular-tests.el --- test image functions with circular objects
 
 ;; Copyright (C) 2019, 2021 Free Software Foundation, Inc.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]